<template>
  <InfiniteLoading
    scrollViewClassName="common-page-infinite-scroll-list"
    v-bind="infiniteLoadingProps"
  >
    <template #renderItem="{ item }">
      <OrderCard
        :title="item.orderName"
        :hireType="item.hireType"
        :hireNumber="item.hireNumber"
        :hireEndNumber="item.hireEndNumber"
        :ageStart="item.ageStart"
        :ageEnd="item.ageEnd"
        :provinceName="item.provinceName"
        :cityName="item.cityName"
        :orderSupplierRefundInfo="item.orderSupplierRefundInfo"
        :src="item.avatarUrl"
        :name="item.contact"
        :jobTitle="item.jobTitle"
        :time="item.lastShelfTime"
        :integratedSalary="item.integratedSalary"
        :userId="item.userId"
        @click="handleClick(item)"
      >
      </OrderCard>
    </template>
  </InfiniteLoading>
  <FloatButton :icon="IconAdd" text="我要供人" @click="goPublish" />
</template>

<script setup lang="ts">
import { useInfiniteLoading, useEvent } from '@12333/hooks';
import * as orderServices from '@12333/services/api/Order';
import { OrderInputType, IndustryCategoryType, ResourceOperateBtnStatus } from '@12333/constants';
import { useAccessPersonalInfo, useCategoryMenu } from '@/hooks';
import { CategoryUtils } from '@12333/utils';
import IconAdd from '@/assets/order/icon-publish.png';
import Taro from '@tarojs/taro';

const queryState = reactive({
  categoryId: '',
});

const {
  ensureCategoryMenu,
  categoryMenuList: industryServicesCategoryList,
  categoryMenuRefetch,
} = useCategoryMenu({
  type: IndustryCategoryType.IndustryServices,
});

onMounted(async () => {
  await ensureCategoryMenu();
  queryState.categoryId = industryServicesCategoryList.value.find((x) =>
    CategoryUtils.isIHasOrder(x.name)
  ).id;
});

useEvent('logout/refresh', async function (data) {
  try {
    await categoryMenuRefetch();
    queryState.categoryId = industryServicesCategoryList.value.find((x) =>
      CategoryUtils.isIHasOrder(x.name)
    ).id;
    infiniteLoadingProps.value.refetch();
  } catch (error) {}
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          { property: 'isRecommend', order: OrderInputType.Desc },
          { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
      categoryId: queryState.categoryId,
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['logout/refresh', 'orderServices/getFrontOrderList', queryState],
    enabled: computed(() => !!queryState.categoryId),
  }
);

function handleClick(item: API.FrontOrderList) {
  Taro.navigateTo({
    url: `${RouterPath.orderDetail}?id=${item.id}`,
  });
}

const goPublish = useAccessPersonalInfo(() => {
  Taro.navigateTo({
    url: `${RouterPath.publishResource}?resourceOperateBtnStatus=${ResourceOperateBtnStatus.Add}`,
  });
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.order-page-list {
  @include listScrollView;
  @include infiniteLoadingInTabBarPage;
}
</style>
